Factores
1 Introduccin
2 Crear un factor
2.1 El nmero de los niveles. La funcin nlevels()
2.2 Deshacer un factor
2.3 Indexacin de factores
3 Factores ordenados. La opcin ordered
3.1 Cambiar el orden de los niveles de un factor (no ordenado). Funcin relevel()
4 Generacin de factores a partir de un vector numrico. La funcin cut()
5 Construccin de tablas
5.1 La funcin table()
5.1.1 Frecuencias marginales y frecuencias relativas
5.2 La funcin ftables()
5.3 La funcin xtables()
6 Atributos de un factor
1 Introduccin
Un factor es un tipo especial de vector que toma un nmero limitado de valores y que contiene informacin extra. La informacin extra de un factor, es el registro de los distintitos valores que puede tomar el vector. A estos distintos valores se les denomina niveles (levels).

Los factores se suelen utilizar con variables categricas. En este tipo de variables se almacena la informacin de forma descriptiva y no cuantitativa.

La informacin en los factores se almacena como un vector de valores enteros que se corresponden con un conjunto de valores cadena. Estas cadenas de caracteres son las que se muestran cuando se imprime el factor.

En resumen, en un factor se guardan:
  
  Los valores distintos que puede tomar el factor, los niveles, y sus correspondientes etiquetas.
El nmero de elementos existentes de cada uno de los niveles en cada uno de ellos.
Los niveles es una informacin suplementaria de la variable estadstica guardada en el factor.
La informacin de los niveles permite realizar una mejor depuracin de datos.
Ciertas funciones exigen que las variables categricas estn en forma de factor (en algunas situaciones)
Por ejemplo, si se quiere almacenar la informacin sobre el tiempo de varias localidades se puede utilizar una variable cuantitativa que registre la temperatura en grados Celsius o bien una variable categrica que recoja la informacin del tiempo como, "tiempo frio", "bueno", "lluvioso.

Tanto la informacin cuantitativa como la cualitativa se puede almacernar en vectores numricos o de caracteres. Sin embargo, hay situaciones en que esta estructura no es la ms adecuada. Por ejemplo, al realizar un modelo estadstico las variables categrica intervienen en estos modelos de forma diferente a como lo hacen las variables numricas, al codificar estas variables categricas como factores el modelo funcional trata a este tipo de datos de forma adecuada.

2 Crear un factor
La funcin principal para crear un factor es la funcin factor(), su sintaxis es:
  
  factor(x = character(), levels, labels = levels,
         exclude = NA, ordered = is.ordered(x), nmax = NA)
donde


x	vector que se transformar en factor
levels	vector caracter opcional que especifica los posibles valores del factor
labels	vector caracter opcional que especifica las etiquetas de los niveles del factor
exclude	vector que especifica que valores deben ser excluidos del conjunto de niveles,
debe ser del mismo tipo que x
ordered	bandera lgica que determina si los niveles estn ordenados o no
nmax	lmite superior del nmero de niveles
De todas formas el nico argumento que necesita la funcin factor() para crear un factor es un vector de valores x. El vector x puede ser un vector numrico pero los niveles de los factores son siempre cadenas de caracteres.

Ejemplo 1

Supongamos los datos siguientes:
  
Nombre	Sexo	Cdigo de sexo
Pepe	H	1
Luca	M	2
Jorge	H	1
Juana	M	2
Mara	M	2
Luis	H	1
Estos datos se pueden almacenar como,

nombre  <- c("Pepe","Luca", "Jorge","Juana","Mara","Luis") # Vector carcter
sexo    <- c("H","M","H","M","M","H")                        # Vector carcter
cod.sexo <- c(1,2,1,2,2,1)                                   # Vector numrico
El almacenar el cdigo de la variable sexo en un vector numrico no es lo ms adecuado, obviamente los nmeros 1 y 2 en esta situacin no tienen valor numrico.

Los niveles de un factor son los posibles valores que puede tomar el objeto declarado como factor. En nuestro ejemplo, cod.sexo guarda los valores que tiene dos niveles, estos son 1 y 2 (pero no como valores numricos). Adems, se utilizar la opcin `labels para poner nombres a los niveles del factor: "Hombre" para el nivel 1 y "Mujer para el nivel 2.

sexo.factor1 <- factor(x=cod.sexo,
                       levels=c(1,2))

sexo.factor1
## [1] 1 2 1 2 2 1
## Levels: 1 2
El vector cod.sexo sigue siendo un vector numrico con el que se puede realizar cualquier tipo de clculo

mean(cod.sexo)
## [1] 1.5
Mientras que sexo.factor1 es un objeto factor y no permite operaciones aritmticas.

mean(sexo.factor1)
## Warning in mean.default(sexo.factor1): argument is not numeric or logical:
## returning NA
## [1] NA
Otras funciones asociadas a los factores son:
  
  as.factor()
is.factor()
length() Nmero de elementos en el factor (no los niveles).
Ejemplo 2

Los meses del ao

numeros <- 1:12
mes     <- as.factor(numeros)
mes
##  [1] 1  2  3  4  5  6  7  8  9  10 11 12
## Levels: 1 2 3 4 5 6 7 8 9 10 11 12
Ponemos las etiquetas

levels(mes) <- c("Enero","Febrero","Marzo","Abril","Mayo","Junio","Julio","Agosto","Septiembre","Octubre","Noviembre", "Diciembre")
mes
##  [1] Enero      Febrero    Marzo      Abril      Mayo       Junio     
##  [7] Julio      Agosto     Septiembre Octubre    Noviembre  Diciembre 
## 12 Levels: Enero Febrero Marzo Abril Mayo Junio Julio ... Diciembre
Hubiera sido ms sencillo en ingls,

mes2 <- factor(1:12, levels=seq(1,12), labels=month.name)
mes2
##  [1] January   February  March     April     May       June      July     
##  [8] August    September October   November  December 
## 12 Levels: January February March April May June July August ... December
Ejemplo 3

Nmeros romanos

datos <- c(1,2,2,3,1,2,3,3,1,2,3,3,1)
fdatos <- factor(datos)
fdatos
##  [1] 1 2 2 3 1 2 3 3 1 2 3 3 1
## Levels: 1 2 3
# Utilizando la opcin labels con el factor fdatos
rdatos <- factor(fdatos, labels = c("I","II","III"))
rdatos
##  [1] I   II  II  III I   II  III III I   II  III III I  
## Levels: I II III
2.1 El nmero de los niveles. La funcin nlevels()
Los niveles de un factor se pueden disminuir o aumentar. Para disminuir el nmero de factores, por ejemplo, porqu una categora tiene pocos efectivos y es conveniente unirla con otra, un procedimiento es el siguiente,

Ejemplo 4

# Calificaciones posibles
notas <- factor(c("suspenso","aprobado","notable","aprobado","sobresaliente","aprobado"))
notas
## [1] suspenso      aprobado      notable       aprobado      sobresaliente
## [6] aprobado     
## Levels: aprobado notable sobresaliente suspenso
levels(notas)
## [1] "aprobado"      "notable"       "sobresaliente" "suspenso"
# Disminuir niveles
levels(notas) <- list(NoPasa = c("Suspenso"),
                      Pasa   = c("aprobado", "notable", "sobresaliente"))
levels(notas)
## [1] "NoPasa" "Pasa"
# Aumentar niveles
notas <- factor(c("suspenso","aprobado","notable","aprobado","sobresaliente","aprobado"))
notas
## [1] suspenso      aprobado      notable       aprobado      sobresaliente
## [6] aprobado     
## Levels: aprobado notable sobresaliente suspenso
# El nmero de factores se calcula con
length(levels(notas))
## [1] 4
# O bien con la funcin nlevels()
nlevels(notas)
## [1] 4
# Aadimos un nuevo nivel
levels(notas)[5] <- "muy deficiente"
levels(notas)
## [1] "aprobado"       "notable"        "sobresaliente"  "suspenso"      
## [5] "muy deficiente"
# Tambin se podra haber hecho
levels(notas) <- c(levels(notas), "matrcula de honor")
levels(notas)
## [1] "aprobado"           "notable"            "sobresaliente"     
## [4] "suspenso"           "muy deficiente"     "matrcula de honor"
# Nuevo nmero de niveles
nlevels(notas)
## [1] 6
Ejemplo 5 Volvamos al factor mesdel ejemplo anterior y supongamos que queremos disminuir el nmero de niveles para considerar unicamente las estaciones.

mes <- factor(1:12, levels=seq(1,12), 
              labels=c("Enero","Febrero","Marzo","Abril","Mayo","Junio","Julio","Agosto","Septiembre","Octubre","Noviembre", "Diciembre"))
levels(mes)
##  [1] "Enero"      "Febrero"    "Marzo"      "Abril"      "Mayo"      
##  [6] "Junio"      "Julio"      "Agosto"     "Septiembre" "Octubre"   
## [11] "Noviembre"  "Diciembre"
Para disminuir el nmero de niveles se ejecuta,

levels(mes) <- list(invierno=c("Enero","Febrero","Marzo"), 
                    primavera=c("Abril","Mayo","Junio"), 
                    verano=c("Julio","Agosto","Septiembre"), 
                    otoo=c("Octubre","Noviembre", "Diciembre"))
levels(mes)
## [1] "invierno"  "primavera" "verano"    "otoo"
mes
##  [1] invierno  invierno  invierno  primavera primavera primavera verano   
##  [8] verano    verano    otoo     otoo     otoo    
## Levels: invierno primavera verano otoo
2.2 Deshacer un factor
Para eliminar la estructura de un factor se utiliza la funcin as.vector().

nombre  <- c("Pepe","Luca", "Jorge","Juana","Mara","Luis") # Vector carcter
sexo    <- c("H","M","H","M","M","H")                        # Vector carcter
cod.sexo <- c(1,2,1,2,2,1) 

sexo.factor1 <- factor(x = cod.sexo,
                       levels=c(1,2))

sexo.factor1
## [1] 1 2 1 2 2 1
## Levels: 1 2
no.factor1 <- as.vector(sexo.factor1)
no.factor1
## [1] "1" "2" "1" "2" "2" "1"
sexo.factor2 <- factor(x = cod.sexo,
                       levels=c(1,2),
                       labels=c("Hombre","Mujer"))
sexo.factor2
## [1] Hombre Mujer  Hombre Mujer  Mujer  Hombre
## Levels: Hombre Mujer
no.factor2 <- as.vector(sexo.factor2)
no.factor2
## [1] "Hombre" "Mujer"  "Hombre" "Mujer"  "Mujer"  "Hombre"
Si el factor en numrico y se quiere convertirlo en un vector numrico hay que utilizar una combinacin de funciones.

sexo.factor1
## [1] 1 2 1 2 2 1
## Levels: 1 2
class(as.vector(sexo.factor1))
## [1] "character"
as.numeric(as.vector(sexo.factor1))
## [1] 1 2 1 2 2 1
2.3 Indexacin de factores
Los elementos de un factor se indexan de igual forma que se hace con un vector, es decir por medio de los corchetes [].

mes[4]
## [1] primavera
## Levels: invierno primavera verano otoo
3 Factores ordenados. La opcin ordered
En R hay dos tipos de factores:
  
  Factores nominales (no ordenados): No existe relacin de orden entre los posibles valores del vector, es decir entre los niveles del factor. Por ejemplo, nmeros de telfono, colores, etc. Presentan los niveles ordenados alfabticamente o en el orden que se especifique en su creacin.
Ejemplo 6 Niveles alfabticamente

CastillaLeon <- c("Len", "Palencia", "Burgos", "Soria", "Zamora", "Valladolid", "Segovia", "Salamanca", "Avila")

CyL.factor1 <- as.factor(CastillaLeon)
CyL.factor1
## [1] Len       Palencia   Burgos     Soria      Zamora     Valladolid
## [7] Segovia    Salamanca  Avila     
## 9 Levels: Avila Burgos Len Palencia Salamanca Segovia ... Zamora
# Est ordenado?
is.ordered(CyL.factor1)
## [1] FALSE
Ejemplo 7 Niveles segn introduccin

CyL.factor2 <- factor(x = c("Len", "Palencia", "Burgos", "Soria", "Zamora", "Valladolid", "Segovia", "Salamanca", "Avila"),
                      levels = c("Len", "Palencia", "Burgos", "Soria", "Zamora", "Valladolid", "Segovia", "Salamanca", "Avila"))
CyL.factor2
## [1] Len       Palencia   Burgos     Soria      Zamora     Valladolid
## [7] Segovia    Salamanca  Avila     
## 9 Levels: Len Palencia Burgos Soria Zamora Valladolid ... Avila
# Est ordenado?
is.ordered(CyL.factor2)
## [1] FALSE
Factores ordinales: Existe una relacin de orden entre los niveles del factor, se utiliza para realizar comparaciones. Por ejemplo, meses del ao, grupos de edad, etc. Para declarar que el factor es ordenado se utiliza la opcin ordered=TRUE, por defecto el factor es no ordenado.
El orden en que se declaran los niveles determina el orden en que aparecer la informacin en tablas o grficos. Esta informacin es relevante en modelos en los que se considera un nivel "base".

Ejemplo 8 Ordenado alfabticamente

CastillaLeon <- c("Len", "Palencia", "Burgos", "Soria", "Zamora", "Valladolid", "Segovia", "Salamanca", "Avila")

CyL.factor3 <- ordered(CastillaLeon)
CyL.factor3
## [1] Len       Palencia   Burgos     Soria      Zamora     Valladolid
## [7] Segovia    Salamanca  Avila     
## 9 Levels: Avila < Burgos < Len < Palencia < Salamanca < ... < Zamora
# Est ordenado?
is.ordered(CyL.factor3)
## [1] TRUE
Ejemplo 9 Ordenado segn el usuario

CyL.factor4 <- ordered(x = c("Len", "Palencia", "Burgos", "Soria", "Zamora", "Valladolid", "Segovia", "Salamanca", "Avila"),
                       levels = c("Len", "Palencia", "Burgos", "Soria", "Zamora", "Valladolid", "Segovia", "Salamanca", "Avila"))
CyL.factor4
## [1] Len       Palencia   Burgos     Soria      Zamora     Valladolid
## [7] Segovia    Salamanca  Avila     
## 9 Levels: Len < Palencia < Burgos < Soria < Zamora < ... < Avila
# Est ordenado?
is.ordered(CyL.factor4)
## [1] TRUE
# Comparaciones
CyL.factor4[3] < CyL.factor4[4]
## [1] TRUE
CyL.factor4[2] > CyL.factor4[7]
## [1] FALSE
Ejemplo 10

El vector meses guarda los datos de los meses en que se ha realizado un tipo particular de operacin financiera. El factor meses.factor es no ordenado, el orden de los niveles es el orden con el que aparecen en el vector de datos.

meses <- c("Marzo","Abril","Octubre", "Abril","Enero","Junio","Diciembre","Julio", "Septiembre", 
           "Agosto", "Febrero","Mayo", "Agosto", "Octubre", "Enero", "Noviembre", "Noviembre",
           "Mayo","Abril", "Agosto", "Julio" )
meses.factor <- factor(meses)
table(meses.factor)
## meses.factor
##      Abril     Agosto  Diciembre      Enero    Febrero      Julio 
##          3          3          1          2          1          2 
##      Junio      Marzo       Mayo  Noviembre    Octubre Septiembre 
##          1          1          2          2          2          1
Para forzar que el orden sea el orden natural de los meses cremos meses.factor2.

meses.factor1 <- factor(x=meses,
                        levels=c("Enero","Febrero","Marzo","Abril","Mayo","Junio", "Julio",
                                 "Agosto","Septiembre","Octubre","Noviembre", "Diciembre"))
meses.factor1
##  [1] Marzo      Abril      Octubre    Abril      Enero      Junio     
##  [7] Diciembre  Julio      Septiembre Agosto     Febrero    Mayo      
## [13] Agosto     Octubre    Enero      Noviembre  Noviembre  Mayo      
## [19] Abril      Agosto     Julio     
## 12 Levels: Enero Febrero Marzo Abril Mayo Junio Julio ... Diciembre
is.ordered(meses.factor1)
## [1] FALSE
table(meses.factor1)
## meses.factor1
##      Enero    Febrero      Marzo      Abril       Mayo      Junio 
##          2          1          1          3          2          1 
##      Julio     Agosto Septiembre    Octubre  Noviembre  Diciembre 
##          2          3          1          2          2          1
3.1 Cambiar el orden de los niveles de un factor (no ordenado). Funcin relevel()
En R la funcin relevel() permite cambiar el un orden de los niveles de un factor no ordenado. En el ejemplo siguiente,

sexo <- c(rep("mujer",700), rep("hombre",570)) # Vector de 1270 elementos
sexo.f <- factor(sexo)    # Se convierte un vector de caracteres en un factor
levels(sexo.f)            # Niveles del factor sexo.f
## [1] "hombre" "mujer"
is.ordered(sexo.f)        # Factor no ordenado. No hay que confundir factor ordenado con orden de los niveles
## [1] FALSE
Es decir en el factor sexo.f hay dos niveles y el orden en el que se han almacenado es "hombre", "mujer" (orden alfabtico). Para cambiar el orden se emplea la funcin relevel(),

sexo.f <- relevel(sexo.f, ref="mujer")
levels(sexo.f)
## [1] "mujer"  "hombre"
Sintaxis de relevel() {stats}

relevel(x, ref, ...)
donde


x	factor no ordenado
ref	valor de referencia del nivel
4 Generacin de factores a partir de un vector numrico. La funcin cut()
Para crear un factor a partir de una variable numrica es preciso primero discretizarla para despus categorizarla. En R, la funcin que permite hacer esto es la funcin cut().

Sintaxis

cut(x, breaks, labels = NULL,
    
    include.lowest = FALSE, right = TRUE, dig.lab = 3,
    
    ordered_result = FALSE, ...)

Argumentos	
x	vector numrico donde estn los datos continuos.
breaks	vector donde se especifican los puntos de corte para discretizar la variable.
Al menos debe tener un valor.
labels	etiquetas para los niveles que se obtienen. Por defecto, las etiquetas son del tipo "(a,b]".
Si labels=FALSE, no se devuelve un factor si no un vector donde los
cdigos son nmeros enteros consecutivos.
include.lowest	argumento lgico que indica si se debe incluir los x[i] iguales al
valor inferior (superior si right=FALSE) del intervalo.
right	argumento lgico. Si right=TRUE, los intervalos son abiertos por la izquierda y cerrados por la derecha,
(,]. Si right=FALSE, el reciproco.
dig.lab	argumento que toma valores enteros. Si no se declaran etiquetas, este argumento determina el nmero
de dgitos que se utilizarn en el formato de los puntos de corte.
orederd_result	argumento lgico que indica si el factor es ordenado o no.
.	otros argumentos pasados dese otras funciones.
Ejemplo 7
#ENTR EN EXAMEN
Supongamos una variable altura que se distribuye segn una N(??=172,??=5). Se dispone de una muestra de 216 personas y se quiere discretizar en tres categoras, "bajo" = <=160, 160 < "medio" <= 180, "alto" >180.

Los datos son:
  
  sexo <- c(rep("mujer",700), rep("hombre",570)) # Vector de 1270 elementos
sexo.f <- factor(sexo)    # Se convierte un vector de carcteres en un factor
levels(sexo.f)            # Niveles del factor sexo.f
## [1] "hombre" "mujer"
altura <- rnorm(216,mean=172,sd=5)
hist(altura, freq=FALSE, 
     main='Histograma de altura',
     xlab="altura en cm", 
     ylab='Densidad',
     ylim=c(0,0.08))
points(density(altura), type='l', col='darkblue')


La variable discretizada es,

altura.d <- cut(altura, 
                breaks=c(min(altura),160,180,max(altura)))
head(altura.d)
## [1] (160.1,180] (160.1,180] (160.1,180] (160.1,180] (160.1,180] (160.1,180]
## Levels: (160,160.1] (160.1,180] (180,183.5]
which(min(altura)==altura)  # El mnimo valor de altura no pertenece a ningun intervalo
## [1] 147
which(is.na(altura.d))
## integer(0)
Se puede solucionar con,

altura.d <- cut(altura, 
                breaks=c(min(altura)-1,160,180,max(altura)))
head(altura.d)
## [1] (160,180] (160,180] (160,180] (160,180] (160,180] (160,180]
## Levels: (159,160] (160,180] (180,183]
Para poner otras etiquetas,

altura.d <- cut(altura, 
                breaks=c(min(altura)-1,160,180,max(altura)), 
                labels=c("bajo","medio","alto"))
tail(altura.d)
## [1] medio medio medio medio medio medio
## Levels: bajo medio alto
Ejemplo 8

El vector ordenes almacena las ordenes de compra de 200 clientes.

ordenes <- round(runif(200,min=1, max=50),0)
head(ordenes)
## [1] 45 25 27 18 33 11
Se quiere clasificar los clientes en 5 grupos de aproximadamente igual nmero de efectivos,

table(cut(ordenes, breaks=5))
## 
## (0.952,10.6]  (10.6,20.2]  (20.2,29.8]  (29.8,39.4]    (39.4,49] 
##           29           48           41           44           38
Otra opcin es utilizar la funcin quantile()para determinar los puntos de corte,

table(cut(ordenes, breaks=quantile(ordenes, probs = seq(0, 1, by = 0.20))))
## 
##    (1,13] (13,22.6] (22.6,30]   (30,39]   (39,49] 
##        39        39        42        40        38
5 Construccin de tablas
Dentro de las operaciones que se realizan con factores la ms comn es la construccin de tablas. En R se disponen de distintas funciones para trabajar con tablas, veremos las funciones siguientes:
  
  table()
xtabs()
ftable().
5.1 La funcin table()
La funcin table() crea tablas de frecuencia cuando trabaja con una variable y tablas de contingencia cuando se aplica a dos variables.

Ejemplo 11: Tabla de frecuencias relativas y absolutas

Supongamos que se encuesta a 25 personas en relacin a su preferencia sobre 4 marcas de un determinado producto, las marcas son A, B, C, D y los resultados son:
  
  A, A, B, B, C, D, C, A, A, B, C, D, D, A, B, C, C, D, C, D, A, A, B, C, C

se pide:
  
  su distribucin de frecuencias absolutas
su distribucin de frecuencias relativas
Solucin

Introducimos los datos,

x <- c("A","A","B","B","C","D","C","A","A","B","C","D","D","A","B","C","C","D","C","D",
       "A","A","B","C","C")
y con la orden table(x) obtenemos las frecuencias absolutas,

table(x)
## x
## A B C D 
## 7 5 8 5
Para calcular las las frecuencias relativas escribimos table(x)/length(x)

table(x)/length(x)
## x
##    A    B    C    D 
## 0.28 0.20 0.32 0.20
Tambin puede dibujar un diagrama de barras, barplot(), tanto de las frecuencias absolutas como de las relativas y lo podemos presentar en un nico grafico,

par(mfrow=c(1,2)) # Instruccin grfica. Divide la pantalla en una fila y dos columnas 

barplot(table(x), 
        main = "Marcas preferidas",
        ylab = "Frecuencias absolutas",
        col  = "orange") 

barplot(table(x)/length(x), 
        main = "Marcas preferidas",
        ylab = "Proporcin",
        col  = "green4") 


Ejemplo 12: Tablas de contingencia

Dado el siguiente conjunto de datos se pide crear una tabla de contingencia.

sexo  <- factor(c(rep("H", 515), rep("M",485)))

gafas <- c(rep("G", 147),rep("NOG", 368), rep("G", 135), rep("NOG", 350))
Solucin

Para crear la tabla ejecutamos el siguiente cdigo,

sexo.gafas <- table(sexo,gafas)

sexo.gafas
##     gafas
## sexo   G NOG
##    H 147 368
##    M 135 350
El objeto sexo.gafas pertenece a la clase "table"

class(sexo.gafas)
## [1] "table"
attributes(sexo.gafas)
## $dim
## [1] 2 2
## 
## $dimnames
## $dimnames$sexo
## [1] "H" "M"
## 
## $dimnames$gafas
## [1] "G"   "NOG"
## 
## 
## $class
## [1] "table"
Se puede asignar nombres a las filas y a las columnas de una tabla o bien cambiarlos. Las funciones que permiten realizar estas acciones son:  colnames() y rownames().

rownames(sexo.gafas) <- c("hombre","mujer")
colnames(sexo.gafas) <- c("Llevas gafas", "No llevas gafas")
sexo.gafas
##         gafas
## sexo     Llevas gafas No llevas gafas
##   hombre          147             368
##   mujer           135             350
5.1.1 Frecuencias marginales y frecuencias relativas
Las funciones margin.table() y prop.table() permiten obtener las frecuencias absolutas y relativas por filas o columnas.

Sintaxis

margin.table(x, margin = NULL)

Argumentos	
x	un array o una tabla
margin	indice (1 por fila, 2 por columna, etc.)
sexo.gafas
##         gafas
## sexo     Llevas gafas No llevas gafas
##   hombre          147             368
##   mujer           135             350
margin.table(sexo.gafas,1)
## sexo
## hombre  mujer 
##    515    485
margin.table(sexo.gafas,2)
## gafas
##    Llevas gafas No llevas gafas 
##             282             718
prop.table(sexo.gafas,1)
##         gafas
## sexo     Llevas gafas No llevas gafas
##   hombre    0.2854369       0.7145631
##   mujer     0.2783505       0.7216495
prop.table(sexo.gafas,2)
##         gafas
## sexo     Llevas gafas No llevas gafas
##   hombre    0.5212766       0.5125348
##   mujer     0.4787234       0.4874652
5.2 La funcin ftables()
La funcin ftables() crea tablas planas lo que es interesante cuando se trabajan con tablas de contingencia de 3 o ms variables.

Ejemplo 13: Tabla de contingencia de 3 variables

ftable(margin.table(sexo.gafas,1))
##  485 515
##         
##    1   1
ftable(prop.table(sexo.gafas,1))
##        gafas Llevas gafas No llevas gafas
## sexo                                     
## hombre          0.2854369       0.7145631
## mujer           0.2783505       0.7216495
5.3 La funcin xtables()
Las funcin xtables() realiza las mismas funciones que la funcin tables(). Sin embargo, la forma de nombrar las variables facilita su aplicacin en los cuadros de datos (los data frame).

Ejemplo 14: Comparacin tables() y xtables()

Los siguientes datos se han recogido de un grupo de personas a las que se les pregunto su opinin sobre un nuevo programa de televisin y su nivel de estudios:
  
  dat <- "Estudios Opinion Numpersonas
bajo malo 1
medio malo 40
alto malo 25
bajo regular 10
medio regular 80
alto regular 12
bajo bueno 30
medio bueno 60
alto bueno 0"

# Introduccin de datos
datos <- read.table(text = dat, header = TRUE)
str(datos)
## 'data.frame':    9 obs. of  3 variables:
##  $ Estudios   : Factor w/ 3 levels "alto","bajo",..: 2 3 1 2 3 1 2 3 1
##  $ Opinion    : Factor w/ 3 levels "bueno","malo",..: 2 2 2 3 3 3 1 1 1
##  $ Numpersonas: int  1 40 25 10 80 12 30 60 0
datos
##   Estudios Opinion Numpersonas
## 1     bajo    malo           1
## 2    medio    malo          40
## 3     alto    malo          25
## 4     bajo regular          10
## 5    medio regular          80
## 6     alto regular          12
## 7     bajo   bueno          30
## 8    medio   bueno          60
## 9     alto   bueno           0
Exprese las frecuencias en proporciones:
  respecto al total (frecuencias relativas conjuntas)
respecto a la variable independiente nivel de estudios (condicionadasde opinin a estudios). Interprete sus valores. Cmo han de efectuarse lascomparaciones entre las proporciones para establecer la posible existencia de asociacin?
  Contraste la hiptesis de independencia del nivel de estudios y opinin sobre el documental.
Caso de resultar dependientes las variables, determine algunas medidas del grado de asociacin.
Solucin

Antes de responder a las preguntas, hay que tener encuenta que los valores se encuentran tabuladas en funcin de los valores de la variable  Numpersonas. En este caso, vamos a construir un conjunto de datos no agrupados.

datos1 <- datos[rep(row.names(datos), datos[,3]),]
head(datos1)
##     Estudios Opinion Numpersonas
## 1       bajo    malo           1
## 2      medio    malo          40
## 2.1    medio    malo          40
## 2.2    medio    malo          40
## 2.3    medio    malo          40
## 2.4    medio    malo          40
Con la funcin table()

tabla1 <- table(datos1$Estudios,datos1$Opinion)  # Tabla construida con table()
Sin embargo, utilizando la funcin xtabs()

tabla2 <- xtabs(Numpersonas ~ ., datos)
tabla2
##         Opinion
## Estudios bueno malo regular
##    alto      0   25      12
##    bajo     30    1      10
##    medio    60   40      80
Las dos tablas son identicas. A partir de cualquiera de ellas se puede terminar el ejercicio.

6 Atributos de un factor
Un objeto factor tiene los siguientes atributos

Atributo	Descripcin
length	nmero de datos
mode	numeric
names	etiquetas de valores
levels	niveles del factor
class	clase "factor"
------	----------